@@ -5,6 +5,7 @@ Tests for IRAFStarFinder.
 
 import itertools
 import os.path as op
+from contextlib import nullcontext
 
 import numpy as np
 import pytest
@@ -13,6 +14,7 @@ from numpy.testing import assert_allclose
 
 from photutils.datasets import make_100gaussians_image
 from photutils.detection.irafstarfinder import IRAFStarFinder
+from photutils.tests.helper import PYTEST_LT_80
 from photutils.utils._optional_deps import HAS_SCIPY
 from photutils.utils.exceptions import NoDetectionsWarning
 
@@ -81,8 +83,14 @@ class TestIRAFStarFinder:
         assert len(tbl) == 4
 
     def test_irafstarfind_largesky(self):
-        with pytest.warns(NoDetectionsWarning,
-                          match='Sources were found, but none pass'):
+        match1 = 'Sources were found, but none pass'
+        ctx1 = pytest.warns(NoDetectionsWarning, match=match1)
+        if PYTEST_LT_80:
+            ctx2 = nullcontext()
+        else:
+            match2 = 'invalid value encountered in divide'
+            ctx2 = pytest.warns(RuntimeWarning, match=match2)
+        with ctx1, ctx2:
             starfinder = IRAFStarFinder(threshold=25.0, fwhm=2.0, sky=100.0)
             tbl = starfinder(DATA)
             assert tbl is None
