@@ -5,10 +5,13 @@ This module provides utilities for PSF-fitting photometry.
 
 import numpy as np
 from astropy.modeling.models import Const2D, Identity, Shift
+from astropy.nddata import NDData
 from astropy.nddata.utils import add_array, extract_array
 from astropy.table import QTable
+from astropy.utils.decorators import deprecated
 
-__all__ = ['prepare_psf_model', 'get_grouped_psf_model', 'subtract_psf']
+__all__ = ['prepare_psf_model', 'get_grouped_psf_model', 'subtract_psf',
+           'grid_from_epsfs']
 
 
 class _InverseShift(Shift):
@@ -129,6 +132,63 @@ def prepare_psf_model(psfmodel, *, xname=None, yname=None, fluxname=None,
     return outmod
 
 
+def _interpolate_missing_data(data, mask, method='cubic'):
+    """
+    Interpolate missing data as identified by the ``mask`` keyword.
+
+    Parameters
+    ----------
+    data : 2D `~numpy.ndarray`
+        An array containing the 2D image.
+
+    mask : 2D bool `~numpy.ndarray`
+        A 2D boolean mask array with the same shape as the input
+        ``data``, where a `True` value indicates the corresponding
+        element of ``data`` is masked.  The masked data points are
+        those that will be interpolated.
+
+    method : {'cubic', 'nearest'}, optional
+        The method of used to interpolate the missing data:
+
+        * ``'cubic'``:  Masked data are interpolated using 2D cubic
+            splines.  This is the default.
+
+        * ``'nearest'``:  Masked data are interpolated using
+            nearest-neighbor interpolation.
+
+    Returns
+    -------
+    data_interp : 2D `~numpy.ndarray`
+        The interpolated 2D image.
+    """
+    from scipy import interpolate
+
+    data_interp = np.array(data, copy=True)
+
+    if len(data_interp.shape) != 2:
+        raise ValueError("'data' must be a 2D array.")
+
+    if mask.shape != data.shape:
+        raise ValueError("'mask' and 'data' must have the same shape.")
+
+    y, x = np.indices(data_interp.shape)
+    xy = np.dstack((x[~mask].ravel(), y[~mask].ravel()))[0]
+    z = data_interp[~mask].ravel()
+
+    if method == 'nearest':
+        interpol = interpolate.NearestNDInterpolator(xy, z)
+    elif method == 'cubic':
+        interpol = interpolate.CloughTocher2DInterpolator(xy, z)
+    else:
+        raise ValueError('Unsupported interpolation method.')
+
+    xy_missing = np.dstack((x[mask].ravel(), y[mask].ravel()))[0]
+    data_interp[mask] = interpol(xy_missing)
+
+    return data_interp
+
+
+@deprecated('1.9.0')
 def get_grouped_psf_model(template_psf_model, star_group, pars_to_set):
     """
     Construct a joint PSF model which consists of a sum of PSF's templated on
@@ -173,6 +233,7 @@ def get_grouped_psf_model(template_psf_model, star_group, pars_to_set):
     return group_psf
 
 
+@deprecated('1.9.0')
 def _extract_psf_fitting_names(psf):
     """
     Determine the names of the x coordinate, y coordinate, and flux from
@@ -204,17 +265,7 @@ def _extract_psf_fitting_names(psf):
     return xname, yname, fluxname
 
 
-def _call_fitter(fitter, psf, x, y, data, weights):
-    """
-    Not all fitters have to support a weight array. This function
-    includes the weight in the fitter call only if really needed.
-    """
-    if np.all(weights == 1.0):
-        return fitter(psf, x, y, data)
-    else:
-        return fitter(psf, x, y, data, weights=weights)
-
-
+@deprecated('1.9.0')
 def subtract_psf(data, psf, posflux, *, subshape=None):
     """
     Subtract PSF/PRFs from an image.
@@ -288,57 +339,155 @@ def subtract_psf(data, psf, posflux, *, subshape=None):
     return subbeddata
 
 
-def _interpolate_missing_data(data, mask, method='cubic'):
+def grid_from_epsfs(epsfs, grid_xypos=None, meta=None):
     """
-    Interpolate missing data as identified by the ``mask`` keyword.
+    Create a GriddedPSFModel from a list of EPSFModels.
+
+    Given a list of EPSFModels, this function will return a GriddedPSFModel.
+    The fiducial points for each input EPSFModel can either be set on each
+    individual model by setting the 'x_0' and 'y_0' attributes, or provided as
+    a list of tuples (``grid_xypos``). If a ``grid_xypos`` list is provided, it
+    must match the length of input EPSFs. In either case, the fiducial points
+    must be on a grid.
+
+    Optionally, a ``meta`` dictionary may be provided for the
+    output GriddedPSFModel. If this dictionary contains the keys 'grid_xypos',
+    'oversampling', or 'fill_value', they will be overridden.
+
+    Note: If set on the input EPSFModel (x_0, y_0), then ``origin`` must be the
+    same for each input EPSF. Additionally data units and dimensions must be
+    for each input EPSF, and values for ``flux`` and ``oversampling``, and
+    ``fill_value`` must match as well.
 
     Parameters
     ----------
-    data : 2D `~numpy.ndarray`
-        An array containing the 2D image.
-
-    mask : 2D bool `~numpy.ndarray`
-        A 2D boolean mask array with the same shape as the input
-        ``data``, where a `True` value indicates the corresponding
-        element of ``data`` is masked.  The masked data points are
-        those that will be interpolated.
-
-    method : {'cubic', 'nearest'}, optional
-        The method of used to interpolate the missing data:
-
-        * ``'cubic'``:  Masked data are interpolated using 2D cubic
-            splines.  This is the default.
-
-        * ``'nearest'``:  Masked data are interpolated using
-            nearest-neighbor interpolation.
+    epsfs : list of `photutils.psf.models.EPSFModel`
+        A list of EPSFModels representing the individual PSFs.
+    grid_xypos : list, optional
+        A list of fiducial points (x_0, y_0) for each PSF.
+        If not provided, the x_0 and y_0 of each input EPSF will be considered
+        the fiducial point for that PSF. Default is None.
+    meta : dict, optional
+        Additional metadata for the GriddedPSFModel. Note that, if they exist
+        in the supplied ``meta``, any values under the keys ``grid_xypos`` ,
+        ``oversampling``, or ``fill_value`` will be overridden. Default is None.
 
     Returns
     -------
-    data_interp : 2D `~numpy.ndarray`
-        The interpolated 2D image.
+    GriddedPSFModel: `photutils.psf.GriddedPSFModel`
+        The gridded PSF model created from the input EPSFs.
     """
-    from scipy import interpolate
+    # prevent circular imports
+    from photutils.psf import EPSFModel, GriddedPSFModel
 
-    data_interp = np.array(data, copy=True)
+    x_0s = []  # optional, to store fiducial from input if `grid_xypos` is None
+    y_0s = []
+    data_arrs = []
+    oversampling = None
+    fill_value = None
+    dat_unit = None
+    origin = None
+    flux = None
 
-    if len(data_interp.shape) != 2:
-        raise ValueError("'data' must be a 2D array.")
+    # make sure, if provided, that ``grid_xypos`` is the same length as ``epsfs``
+    if grid_xypos is not None:
+        if len(grid_xypos) != len(epsfs):
+            raise ValueError('``grid_xypos`` must be the same length as ``epsfs``.')
 
-    if mask.shape != data.shape:
-        raise ValueError("'mask' and 'data' must have the same shape.")
+    # loop over input once
+    for i, epsf in enumerate(epsfs):
 
-    y, x = np.indices(data_interp.shape)
-    xy = np.dstack((x[~mask].ravel(), y[~mask].ravel()))[0]
-    z = data_interp[~mask].ravel()
+        # check input type
+        if not isinstance(epsf, EPSFModel):
+            raise ValueError('All input `epsfs` must be of type '
+                             '`photutils.psf.models.EPSFModel`.')
 
-    if method == 'nearest':
-        interpol = interpolate.NearestNDInterpolator(xy, z)
-    elif method == 'cubic':
-        interpol = interpolate.CloughTocher2DInterpolator(xy, z)
-    else:
-        raise ValueError('Unsupported interpolation method.')
+        # get data array from EPSF
+        data_arrs.append(epsf.data)
 
-    xy_missing = np.dstack((x[mask].ravel(), y[mask].ravel()))[0]
-    data_interp[mask] = interpol(xy_missing)
+        if i == 0:
+            # EPSFModel allows a tuple for oversampling factor in x, y,
+            # but GriddedPSFModel requires it to be a single scalar value.
+            # Keep this condition for now by checking that x and y match
+            if np.isscalar(epsf.oversampling):
+                oversampling = epsf.oversampling
+            else:
+                if epsf.oversampling[0] != epsf.oversampling[1]:
+                    raise ValueError('Oversampling must be the same in x and y.')
+                oversampling = epsf.oversampling[0]
 
-    return data_interp
+            # same for fill value and flux, grid will have a single value
+            # so it should be the same for all input, and error if not.
+            fill_value = epsf.fill_value
+
+            # check that origins are the same
+            if grid_xypos is None:
+                origin = epsf.origin
+
+            flux = epsf.flux
+
+            # if theres a unit, those should also all be the same
+            try:
+                dat_unit = epsf.data.unit
+            except AttributeError:
+                pass  # just keep as None
+
+        else:
+            if np.isscalar(epsf.oversampling):
+                if epsf.oversampling != oversampling:
+                    raise ValueError('All input EPSFModels must have the same '
+                                     'value for ``oversampling``.')
+                else:
+                    if epsf.oversampling[0] != epsf.oversampling[1] != oversampling:
+                        raise ValueError('All input EPSFModels must have the '
+                                         'same value for ``oversampling``.')
+
+            if epsf.fill_value != fill_value:
+                raise ValueError('All input EPSFModels must have the same value '
+                                 'for ``fill_value``.')
+
+            if epsf.data.ndim != data_arrs[0].ndim:
+                raise ValueError('All input EPSFModels must have data with the '
+                                 'same dimensions.')
+
+            try:
+                unitt = epsf.data_unit
+                if unitt != dat_unit:
+                    raise ValueError('All input data must have the same unit.')
+            except AttributeError:
+                if dat_unit is not None:
+                    raise ValueError('All input data must have the same unit.')
+
+            if epsf.flux != flux:
+                raise ValueError('All input EPSFModels must have the same value '
+                                 'for ``flux``.')
+
+        if grid_xypos is None:  # get gridxy_pos from x_0, y_0 if not provided
+            x_0s.append(epsf.x_0.value)
+            y_0s.append(epsf.y_0.value)
+
+            # also check that origin is the same, if using x_0s and y_0s from input
+            if epsf.origin != origin:
+                raise ValueError('If using ``x_0``, ``y_0`` as fiducial point,'
+                                 '``origin`` must match for each input EPSF.')
+
+    # if not supplied, use from x_0, y_0 of input EPSFs as fiducuals
+    # these are checked when GriddedPSFModel is created to make sure they
+    # are actually on a grid.
+    if grid_xypos is None:
+        grid_xypos = list(zip(x_0s, y_0s))
+
+    data_cube = np.stack(data_arrs, axis=0)
+
+    if meta is None:
+        meta = {}
+    # add required keywords to meta
+    meta['grid_xypos'] = grid_xypos
+    meta['oversampling'] = oversampling
+    meta['fill_value'] = fill_value
+
+    data = NDData(data_cube, meta=meta)
+
+    grid = GriddedPSFModel(data, fill_value=fill_value)
+
+    return grid
