@@ -6,14 +6,15 @@ segment within a segmentation image.
 
 import inspect
 import warnings
-from copy import deepcopy
+from copy import copy, deepcopy
 
 import numpy as np
 from astropy.utils import lazyproperty
-from astropy.utils.decorators import deprecated_renamed_argument
 from astropy.utils.exceptions import AstropyUserWarning
 
 from photutils.aperture import BoundingBox
+from photutils.utils._optional_deps import HAS_RASTERIO, HAS_SHAPELY
+from photutils.utils._parameters import as_pair
 from photutils.utils.colormaps import make_random_cmap
 
 __all__ = ['SegmentationImage', 'Segment']
@@ -120,9 +121,20 @@ class SegmentationImage:
         of the ``labels`` attribute.
         """
         segments = []
-        for label, slc, bbox, area in zip(self.labels, self.slices, self.bbox,
-                                          self.areas):
-            segments.append(Segment(self.data, label, slc, bbox, area))
+
+        if HAS_RASTERIO and HAS_SHAPELY:
+            for label, slc, bbox, area, polygon in zip(self.labels,
+                                                       self.slices,
+                                                       self.bbox,
+                                                       self.areas,
+                                                       self.polygons):
+                segments.append(Segment(self.data, label, slc, bbox, area,
+                                        polygon=polygon))
+        else:
+            for label, slc, bbox, area in zip(self.labels, self.slices,
+                                              self.bbox, self.areas):
+                segments.append(Segment(self.data, label, slc, bbox, area))
+
         return segments
 
     @property
@@ -235,7 +247,7 @@ class SegmentationImage:
 
         Parameters
         ----------
-        labels : int, array-like (1D, int)
+        labels : int, array_like (1D, int)
             The label numbers(s) to find.
 
         Returns
@@ -327,7 +339,7 @@ class SegmentationImage:
 
         Parameters
         ----------
-        labels : int, 1D array-like (int)
+        labels : int, 1D array_like (int)
             The label(s) for which to return areas.  Label must be
             non-zero.
 
@@ -388,7 +400,7 @@ class SegmentationImage:
 
         Parameters
         ----------
-        labels : int, 1D array-like (int)
+        labels : int, 1D array_like (int)
             The label(s) to check.
 
         Raises
@@ -549,7 +561,7 @@ class SegmentationImage:
 
         Parameters
         ----------
-        labels : int, array-like (1D, int)
+        labels : int, array_like (1D, int)
             The label numbers(s) to reassign.
 
         new_label : int
@@ -742,7 +754,7 @@ class SegmentationImage:
 
         Parameters
         ----------
-        labels : int, array-like (1D, int)
+        labels : int, array_like (1D, int)
             The label number(s) to keep.
 
         relabel : bool, optional
@@ -853,7 +865,7 @@ class SegmentationImage:
 
         Parameters
         ----------
-        labels : int, array-like (1D, int)
+        labels : int, array_like (1D, int)
             The label number(s) to remove.
 
         relabel : bool, optional
@@ -1041,25 +1053,45 @@ class SegmentationImage:
             remove_labels = list(set(remove_labels) - set(interior_labels))
         self.remove_labels(remove_labels, relabel=relabel)
 
-    def make_source_mask(self, footprint=None):
+    def make_source_mask(self, *, size=None, footprint=None):
         """
         Make a source mask from the segmentation image.
 
-        Use the ``footprint`` keyword to perform binary dilation on the
-        segmentation image.
+        Use the ``size`` or ``footprint`` keyword to perform binary
+        dilation on the segmentation image mask.
 
         Parameters
         ----------
+        size : int or tuple of int, optional
+            The size along each axis of the footprint used for the
+            source dilation. If ``size`` is a scalar, then a square
+            footprint of ``size`` will be used. If ``size`` has two
+            elements, they must be in ``(ny, nx)`` order. ``size``
+            should have odd values for each axis. To perform source
+            dilation, either ``size`` or ``footprint`` must be defined.
+            If they are both defined, then ``footprint`` overrides
+            ``size``.
+
         footprint : 2D `~numpy.ndarray`, optional
             The local footprint used for the source dilation. Non-zero
-            elements are considered `True`.  If `None`, then no dilation
-            is performed.
+            elements are considered `True`. ``size=(n, m)`` is
+            equivalent to ``footprint=np.ones((n, m))``. To perform
+            source dilation, either ``size`` or ``footprint`` must
+            be defined. If they are both defined, then ``footprint``
+            overrides ``size``.
 
         Returns
         -------
         mask : 2D bool `~numpy.ndarray`
             A 2D boolean image containing the source mask.
 
+        Notes
+        -----
+        When performing source dilation, using a square footprint
+        will be much faster than using other shapes (e.g., a circular
+        footprint). Source dilation also is slower for larger images and
+        larger footprints.
+
         Examples
         --------
         >>> import numpy as np
@@ -1068,9 +1100,38 @@ class SegmentationImage:
         >>> data = np.zeros((7, 7), dtype=int)
         >>> data[3, 3] = 1
         >>> segm = SegmentationImage(data)
+        >>> segm.data
+        array([[0, 0, 0, 0, 0, 0, 0],
+               [0, 0, 0, 0, 0, 0, 0],
+               [0, 0, 0, 0, 0, 0, 0],
+               [0, 0, 0, 1, 0, 0, 0],
+               [0, 0, 0, 0, 0, 0, 0],
+               [0, 0, 0, 0, 0, 0, 0],
+               [0, 0, 0, 0, 0, 0, 0]])
+
+        >>> mask0 = segm.make_source_mask()
+        >>> mask0
+        array([[False, False, False, False, False, False, False],
+               [False, False, False, False, False, False, False],
+               [False, False, False, False, False, False, False],
+               [False, False, False,  True, False, False, False],
+               [False, False, False, False, False, False, False],
+               [False, False, False, False, False, False, False],
+               [False, False, False, False, False, False, False]])
+
+        >>> mask1 = segm.make_source_mask(size=3)
+        >>> mask1
+        array([[False, False, False, False, False, False, False],
+               [False, False, False, False, False, False, False],
+               [False, False,  True,  True,  True, False, False],
+               [False, False,  True,  True,  True, False, False],
+               [False, False,  True,  True,  True, False, False],
+               [False, False, False, False, False, False, False],
+               [False, False, False, False, False, False, False]])
+
         >>> footprint = circular_footprint(radius=3)
-        >>> mask = segm.make_source_mask(footprint=footprint)
-        >>> mask
+        >>> mask2 = segm.make_source_mask(footprint=footprint)
+        >>> mask2
         array([[False, False, False,  True, False, False, False],
                [False,  True,  True,  True,  True,  True, False],
                [False,  True,  True,  True,  True,  True, False],
@@ -1079,75 +1140,158 @@ class SegmentationImage:
                [False,  True,  True,  True,  True,  True, False],
                [False, False, False,  True, False, False, False]])
         """
+        mask = self._data.astype(bool)
+
         if footprint is None:
-            return self._data.astype(bool)
+            if size is None:
+                return mask
+            else:
+                size = as_pair('size', size, check_odd=False)
+                footprint = np.ones(size)
 
-        from scipy.ndimage import binary_dilation
+        if np.all(footprint):
+            # With a rectangular footprint, scipy grey_dilation is
+            # currently much faster than binary_dilation (separable
+            # footprint). grey_dilation and binary_dilation are identical
+            # for binary inputs (equivalent to a 2D maximum filter).
+            from scipy.ndimage import grey_dilation
+            return grey_dilation(mask, footprint=footprint)
+        else:
+            from scipy.ndimage import binary_dilation
+            return binary_dilation(mask, structure=footprint)
 
-        return binary_dilation(self._data.astype(bool), structure=footprint)
-
-    def outline_segments(self, mask_background=False):
+    @lazyproperty
+    def _geo_polygons(self):
         """
-        Outline the labeled segments.
+        A list of polygons representing each source segment.
 
-        The "outlines" represent the pixels *just inside* the segments,
-        leaving the background pixels unmodified.
+        Each item in the list is tuple of (polygon, value) where the
+        polygon is a GeoJSON-like dict and the value is the label from
+        the segmentation image.
+        """
+        from rasterio.features import shapes
+
+        polygons = list(shapes(self.data.astype('int32'), connectivity=8))
+        polygons.sort(key=lambda x: x[1])
+
+        # do not include polygons for background (label = 0)
+        return polygons[1:]
+
+    @lazyproperty
+    def polygons(self):
+        """
+        A list of `Shapely <https://shapely.readthedocs.io/>`_ polygons
+        representing each source segment.
+        """
+        from shapely.geometry import shape
+
+        polygons = []
+        for geo_poly in self._geo_polygons:
+            polygons.append(shape(geo_poly[0]))
+        return polygons
+
+    def to_patches(self, *, origin=(0, 0), **kwargs):
+        """
+        Return a list of `~matplotlib.patches.Polygon` objects
+        representing each source segment.
+
+        By default, the polygon patch will have a white edge color and
+        no face color.
 
         Parameters
         ----------
-        mask_background : bool, optional
-            Set to `True` to mask the background pixels (labels = 0) in
-            the returned array.  This is useful for overplotting the
-            segment outlines.  The default is `False`.
+        origin : array_like, optional
+            The ``(x, y)`` position of the origin of the displayed
+            image.
+
+        **kwargs : `dict`
+            Any keyword arguments accepted by
+            `matplotlib.patches.Polygon`.
+        """
+        from matplotlib.patches import Polygon
+
+        origin = np.array(origin)
+        patch_kwargs = {'edgecolor': 'white', 'facecolor': 'none'}
+        patch_kwargs.update(kwargs)
+
+        patches = []
+        for geo_poly in self._geo_polygons:
+            xy = (np.array(geo_poly[0]['coordinates'][0]) - origin
+                  - np.array((0.5, 0.5)))
+            patches.append(Polygon(xy, **patch_kwargs))
+
+        return patches
+
+    def plot_patches(self, *, ax=None, origin=(0, 0), labels=None, **kwargs):
+        """
+        Plot the `~matplotlib.patches.Polygon` objects for the source
+        segments on a matplotlib `~matplotlib.axes.Axes` instance.
+
+        Parameters
+        ----------
+        ax : `matplotlib.axes.Axes` or `None`, optional
+            The matplotlib axes on which to plot.  If `None`, then the
+            current `~matplotlib.axes.Axes` instance is used.
+
+        origin : array_like, optional
+            The ``(x, y)`` position of the origin of the displayed
+            image.
+
+        labels: int or array of int, optional
+            The label numbers whose polygons are to be ploted. If
+            `None`, the polygons for all labels will be plotted.
+
+        **kwargs : `dict`
+            Any keyword arguments accepted by
+            `matplotlib.patches.Polygon`.
 
         Returns
         -------
-        boundaries : `~numpy.ndarray` or `~numpy.ma.MaskedArray`
-            An array with the same shape of the segmentation array
-            containing only the outlines of the labeled segments.  The
-            pixel values in the outlines correspond to the labels in the
-            segmentation array.  If ``mask_background`` is `True`, then
-            a `~numpy.ma.MaskedArray` is returned.
+        patches : list of `~matplotlib.patches.Polygon`
+            A list of matplotlib polygon patches for the plotted
+            polygons. The patches can be used, for example, when adding
+            a plot legend.
 
         Examples
         --------
-        >>> from photutils.segmentation import SegmentationImage
-        >>> data = np.array([[0, 0, 0, 0, 0, 0],
-        ...                  [0, 2, 2, 2, 2, 0],
-        ...                  [0, 2, 2, 2, 2, 0],
-        ...                  [0, 2, 2, 2, 2, 0],
-        ...                  [0, 2, 2, 2, 2, 0],
-        ...                  [0, 0, 0, 0, 0, 0]])
-        >>> segm = SegmentationImage(data)
-        >>> segm.outline_segments()
-        array([[0, 0, 0, 0, 0, 0],
-               [0, 2, 2, 2, 2, 0],
-               [0, 2, 0, 0, 2, 0],
-               [0, 2, 0, 0, 2, 0],
-               [0, 2, 2, 2, 2, 0],
-               [0, 0, 0, 0, 0, 0]])
+        .. plot::
+            :include-source:
+
+            import numpy as np
+            from photutils.segmentation import SegmentationImage
+
+            data = np.array([[1, 1, 0, 0, 4, 4],
+                             [0, 0, 0, 0, 0, 4],
+                             [0, 0, 3, 3, 0, 0],
+                             [7, 0, 0, 0, 0, 5],
+                             [7, 7, 0, 5, 5, 5],
+                             [7, 7, 0, 0, 5, 5]])
+            segm = SegmentationImage(data)
+            segm.imshow(figsize=(5, 5))
+            segm.plot_patches(edgecolor='white', lw=2)
         """
-        from scipy.ndimage import (generate_binary_structure, grey_dilation,
-                                   grey_erosion)
+        import matplotlib.pyplot as plt
 
-        # edge connectivity
-        footprint = generate_binary_structure(self._ndim, 1)
+        if ax is None:
+            ax = plt.gca()
 
-        # mode='constant' ensures outline is included on the array borders
-        eroded = grey_erosion(self.data, footprint=footprint, mode='constant',
-                              cval=0.0)
-        dilated = grey_dilation(self.data, footprint=footprint,
-                                mode='constant', cval=0.0)
+        patches = self.to_patches(origin=origin, **kwargs)
+        if labels is not None:
+            patches = np.array(patches)
+            indices = self.get_indices(labels)
+            patches = patches[indices]
+            if np.isscalar(labels):
+                patches = [patches]
 
-        outlines = ((dilated != eroded) & (self.data != 0)).astype(int)
-        outlines *= self.data
+        for patch in patches:
+            patch = copy(patch)
+            ax.add_patch(patch)
 
-        if mask_background:
-            outlines = np.ma.masked_where(outlines == 0, outlines)
+        if labels is not None:
+            patches = list(patches)
 
-        return outlines
+        return patches
 
-    @deprecated_renamed_argument('axes', 'ax', '1.6.0')
     def imshow(self, ax=None, figsize=None, dpi=None, cmap=None, alpha=None):
         """
         Display the segmentation image in a matplotlib
@@ -1176,7 +1320,7 @@ class SegmentationImage:
             If `None`, then the colormap defined by the `cmap` attribute
             will be used.
 
-        alpha : float, array-like, or `None`, optional
+        alpha : float, array_like, or `None`, optional
             The alpha blending value, between 0 (transparent) and 1
             (opaque). If alpha is an array, the alpha blending values
             are applied pixel by pixel, and alpha must have the same
@@ -1211,7 +1355,7 @@ class SegmentationImage:
         if cmap is None:
             cmap = self.cmap
 
-        return ax.imshow(self.data, cmap=cmap, interpolation='none',
+        return ax.imshow(self.data, cmap=cmap, interpolation='nearest',
                          origin='lower', alpha=alpha)
 
 
@@ -1239,14 +1383,20 @@ class Segment:
 
     area : float
         The area of the segment in pixels**2.
+
+    polygon : Shapely polygon, optional
+        The outline of the segment as a `Shapely
+        <https://shapely.readthedocs.io/>`_ polygon.
     """
 
-    def __init__(self, segment_data, label, slices, bbox, area):
+    def __init__(self, segment_data, label, slices, bbox, area, *,
+                 polygon=None):
         self._segment_data = segment_data
         self.label = label
         self.slices = slices
         self.bbox = bbox
         self.area = area
+        self.polygon = polygon
 
     def __str__(self):
         cls_name = f'<{self.__class__.__module__}.{self.__class__.__name__}>'
@@ -1262,6 +1412,12 @@ class Segment:
     def __repr__(self):
         return self.__str__()
 
+    def _repr_svg_(self):  # pragma: no cover
+        if self.polygon is not None:
+            print(repr(self))
+            return self.polygon._repr_svg_()
+        return None
+
     def __array__(self):
         """
         Array representation of the labeled region (e.g., for
