@@ -10,12 +10,11 @@ import numpy as np
 from astropy.stats import SigmaClip
 from astropy.utils.exceptions import AstropyUserWarning
 
-# pylint: disable-next=E0611
-from photutils.utils._optional_deps import HAS_TQDM
+from photutils.utils._progress_bars import add_progress_bar
 from photutils.utils.footprints import circular_footprint
 
 __all__ = ['ImageDepth']
-__doctest_requires__ = {('ImageDepth', 'ImageDepth.*'): ['scipy']}
+__doctest_requires__ = {('ImageDepth', 'ImageDepth.*'): ['scipy', 'skimage']}
 
 
 class ImageDepth:
@@ -87,13 +86,14 @@ class ImageDepth:
         A list of the number of apertures used for each iteration.
 
     fluxes : list of `~numpy.ndarray`
-        A list of the flux measurements for each iteration.
+        A list of arrays containing the flux measurements for each
+        iteration.
 
-    flux_limits : list
-        A list of the flux limits for each iteration.
+    flux_limits : 1D `~numpy.ndarray`
+        An array of the flux limits for each iteration.
 
-    mag_limits : list
-        A list of the magnitude limits for each iteration.
+    mag_limits : 1D `~numpy.ndarray`
+        An array of the magnitude limits for each iteration.
 
     Notes
     -----
@@ -244,12 +244,6 @@ class ImageDepth:
         # prevent circular import
         from photutils.aperture import CircularAperture
 
-        iter_range = range(self.niters)
-        if self.progress_bar and HAS_TQDM:
-            from tqdm.auto import tqdm  # pragma: no cover
-
-            iter_range = tqdm(iter_range, desc='Image Depths')  # pragma: no cover
-
         if mask is None or not np.any(mask):
             all_xycoords = self._make_all_coords_no_mask(data.shape)
         else:
@@ -264,6 +258,11 @@ class ImageDepth:
             napers2 = 1.5 * self.napers
             napers = int(min(napers2, 0.1 * len(all_xycoords)))
 
+        iter_range = range(self.niters)
+        if self.progress_bar:
+            desc = 'Image Depths'
+            iter_range = add_progress_bar(iter_range, desc=desc)  # pragma: no cover
+
         fluxes = []
         flux_limits = []
         apertures = []
